# MySQL dump 7.1
#
# Host: sql    Database: accounting
#--------------------------------------------------------
# Server version	3.22.32-log

#
# Table structure for table 'login'
#
CREATE TABLE login (
  login char(15),
  start_record timestamp(14)
);

#
# Table structure for table 'logout'
#
CREATE TABLE logout (
  login char(15),
  input_packets int(10),
  output_packets int(10),
  duration int(5),
  ip_address char(15),
  end_record timestamp(14)
);

#
# Table structure for table 'users'
#
CREATE TABLE users (
  login varchar(15) NOT NULL PRIMARY KEY,
  passwd varchar(14),
  name varchar(255),
  status enum('Active','Disabled') DEFAULT 'Active' NOT NULL
);
